==> kopf-0.24.tar.gz: kopf-0.24/tests/authentication/test_reauthentication.py <==
import aiohttp.web
from typing import Optional, AsyncIterator, Tuple

from kopf.clients.auth import APISession, reauthenticated_request, reauthenticated_stream


@reauthenticated_request
async def request_fn(
        x: int,
        *,
        session: Optional[APISession],
) -> Tuple[APISession, int]:
    return session, x + 100


@reauthenticated_stream
async def stream_fn(
        x: int,
        *,
        session: Optional[APISession],
) -> AsyncIterator[Tuple[APISession, int]]:
    yield session, x + 100


async def test_session_is_injected_to_request(
        fake_vault, resp_mocker, aresponses, hostname, resource):

    result = {}
    get_mock = resp_mocker(return_value=aiohttp.web.json_response(result))
    aresponses.add(hostname, resource.get_url(namespace=None, name='xyz'), 'get', get_mock)

    session, result = await request_fn(1)

    assert session is not None
    assert result == 101


async def test_session_is_injected_to_stream(
        fake_vault, resp_mocker, aresponses, hostname, resource):

    result = {}
    get_mock = resp_mocker(return_value=aiohttp.web.json_response(result))
    aresponses.add(hostname, resource.get_url(namespace=None, name='xyz'), 'get', get_mock)

    counter = 0
    async for session, result in stream_fn(1):
        counter += 1

    assert session is not None
    assert result == 101
    assert counter == 1


async def test_session_is_passed_through_to_request(
        fake_vault, resp_mocker, aresponses, hostname, resource):

    result = {}
    get_mock = resp_mocker(return_value=aiohttp.web.json_response(result))
    aresponses.add(hostname, resource.get_url(namespace=None, name='xyz'), 'get', get_mock)

    explicit_session = APISession()
    session, result = await request_fn(1, session=explicit_session)

    assert session is explicit_session
    assert result == 101


async def test_session_is_passed_through_to_stream(
        fake_vault, resp_mocker, aresponses, hostname, resource):

    result = {}
    get_mock = resp_mocker(return_value=aiohttp.web.json_response(result))
    aresponses.add(hostname, resource.get_url(namespace=None, name='xyz'), 'get', get_mock)

    explicit_session = APISession()
    counter = 0
    async for session, result in stream_fn(1, session=explicit_session):
        counter += 1

    assert session is explicit_session
    assert result == 101
    assert counter == 1

==> kopf-0.25.tar.gz: kopf-0.25/tests/authentication/test_reauthentication.py <==
from typing import Optional, AsyncIterator, Tuple

import aiohttp.web

from kopf.clients.auth import APIContext, reauthenticated_request, reauthenticated_stream
from kopf.structs.credentials import ConnectionInfo


@reauthenticated_request
async def request_fn(
        x: int,
        *,
        context: Optional[APIContext],
) -> Tuple[APIContext, int]:
    return context, x + 100


@reauthenticated_stream
async def stream_fn(
        x: int,
        *,
        context: Optional[APIContext],
) -> AsyncIterator[Tuple[APIContext, int]]:
    yield context, x + 100


async def test_session_is_injected_to_request(
        fake_vault, resp_mocker, aresponses, hostname, resource):

    result = {}
    get_mock = resp_mocker(return_value=aiohttp.web.json_response(result))
    aresponses.add(hostname, resource.get_url(namespace=None, name='xyz'), 'get', get_mock)

    context, result = await request_fn(1)

    assert context is not None
    assert result == 101


async def test_session_is_injected_to_stream(
        fake_vault, resp_mocker, aresponses, hostname, resource):

    result = {}
    get_mock = resp_mocker(return_value=aiohttp.web.json_response(result))
    aresponses.add(hostname, resource.get_url(namespace=None, name='xyz'), 'get', get_mock)

    context = None
    counter = 0
    async for context, result in stream_fn(1):
        counter += 1

    assert context is not None
    assert result == 101
    assert counter == 1


async def test_session_is_passed_through_to_request(
        fake_vault, resp_mocker, aresponses, hostname, resource):

    result = {}
    get_mock = resp_mocker(return_value=aiohttp.web.json_response(result))
    aresponses.add(hostname, resource.get_url(namespace=None, name='xyz'), 'get', get_mock)

    explicit_context = APIContext(ConnectionInfo(server='http://irrelevant/'))
    context, result = await request_fn(1, context=explicit_context)

    assert context is explicit_context
    assert result == 101


async def test_session_is_passed_through_to_stream(
        fake_vault, resp_mocker, aresponses, hostname, resource):

    result = {}
    get_mock = resp_mocker(return_value=aiohttp.web.json_response(result))
    aresponses.add(hostname, resource.get_url(namespace=None, name='xyz'), 'get', get_mock)

    explicit_context = APIContext(ConnectionInfo(server='http://irrelevant/'))
    counter = 0
    async for context, result in stream_fn(1, context=explicit_context):
        counter += 1

    assert context is explicit_context
    assert result == 101
    assert counter == 1
